@@ -10,15 +10,11 @@ import (
 	"github.com/weaveworks/eksctl/pkg/awsapi"
 
 	"github.com/aws/aws-sdk-go-v2/service/eks"
-	ekstypes "github.com/aws/aws-sdk-go-v2/service/eks/types"
 	"github.com/hashicorp/go-version"
 	"github.com/kris-nova/logger"
-	"github.com/pkg/errors"
 
 	kubeclient "k8s.io/client-go/kubernetes"
 
-	"github.com/weaveworks/eksctl/pkg/cfn/waiter"
-
 	"github.com/weaveworks/eksctl/pkg/cfn/manager"
 
 	iamoidc "github.com/weaveworks/eksctl/pkg/iam/oidc"
@@ -33,10 +29,9 @@ type Manager struct {
 	oidcManager   *iamoidc.OpenIDConnectManager
 	stackManager  manager.StackManager
 	clientSet     kubeclient.Interface
-	timeout       time.Duration
 }
 
-func New(clusterConfig *api.ClusterConfig, eksAPI awsapi.EKS, stackManager manager.StackManager, withOIDC bool, oidcManager *iamoidc.OpenIDConnectManager, clientSet kubeclient.Interface, timeout time.Duration) (*Manager, error) {
+func New(clusterConfig *api.ClusterConfig, eksAPI awsapi.EKS, stackManager manager.StackManager, withOIDC bool, oidcManager *iamoidc.OpenIDConnectManager, clientSet kubeclient.Interface) (*Manager, error) {
 	return &Manager{
 		clusterConfig: clusterConfig,
 		eksAPI:        eksAPI,
@@ -44,37 +39,32 @@ func New(clusterConfig *api.ClusterConfig, eksAPI awsapi.EKS, stackManager manag
 		oidcManager:   oidcManager,
 		stackManager:  stackManager,
 		clientSet:     clientSet,
-		timeout:       timeout,
 	}, nil
 }
 
-func (a *Manager) waitForAddonToBeActive(ctx context.Context, addon *api.Addon) error {
-	var out *eks.DescribeAddonOutput
-	operation := func() (bool, error) {
-		var err error
-		out, err = a.eksAPI.DescribeAddon(ctx, &eks.DescribeAddonInput{
-			ClusterName: &a.clusterConfig.Metadata.Name,
-			AddonName:   &addon.Name,
-		})
-		if err != nil {
-			return false, err
-		}
-		return out.Addon.Status == ekstypes.AddonStatusActive, nil
+func (a *Manager) waitForAddonToBeActive(ctx context.Context, addon *api.Addon, waitTimeout time.Duration) error {
+	activeWaiter := eks.NewAddonActiveWaiter(a.eksAPI)
+	input := &eks.DescribeAddonInput{
+		ClusterName: &a.clusterConfig.Metadata.Name,
+		AddonName:   &addon.Name,
 	}
+	if err := activeWaiter.Wait(ctx, input, waitTimeout); err != nil {
+		getAddonStatus := func() string {
+			output, describeErr := a.eksAPI.DescribeAddon(ctx, input)
+			if describeErr != nil {
+				return describeErr.Error()
+			}
+			return string(output.Addon.Status)
+		}
 
-	w := waiter.Waiter{
-		Operation: operation,
-		NextDelay: func(_ int) time.Duration {
-			return a.timeout / 10
-		},
-	}
-
-	err := w.WaitWithTimeout(a.timeout)
-	if err != nil {
-		if err == context.DeadlineExceeded {
-			return errors.Errorf("timed out waiting for addon %q to become active, status: %q", addon.Name, out.Addon.Status)
+		switch {
+		case strings.Contains(err.Error(), "exceeded max wait time"):
+			return fmt.Errorf("timed out waiting for addon %q to become active, status: %q", addon.Name, getAddonStatus())
+		case strings.Contains(err.Error(), "waiter state transitioned to Failure"):
+			return fmt.Errorf("addon status transitioned to %q", getAddonStatus())
+		default:
+			return err
 		}
-		return err
 	}
 	logger.Info("addon %q active", addon.Name)
 	return nil
