@@ -4,6 +4,8 @@ import (
 	"context"
 	"time"
 
+	"github.com/aws/amazon-ec2-instance-selector/v2/pkg/selector"
+
 	awseks "github.com/aws/aws-sdk-go-v2/service/eks"
 	ekstypes "github.com/aws/aws-sdk-go-v2/service/eks/types"
 	"github.com/kris-nova/logger"
@@ -36,7 +38,7 @@ func NewUnownedCluster(cfg *api.ClusterConfig, ctl *eks.ClusterProvider, stackMa
 			return ctl.NewStdClientSet(cfg)
 		},
 		newNodeGroupManager: func(cfg *api.ClusterConfig, ctl *eks.ClusterProvider, clientSet kubernetes.Interface) NodeGroupDrainer {
-			return nodegroup.New(cfg, ctl, clientSet)
+			return nodegroup.New(cfg, ctl, clientSet, selector.New(ctl.AWSProvider.Session()))
 		},
 	}
 }
@@ -77,7 +79,7 @@ func (c *UnownedCluster) Delete(ctx context.Context, waitInterval, podEvictionWa
 		}
 
 		nodeGroupManager := c.newNodeGroupManager(c.cfg, c.ctl, clientSet)
-		if err := drainAllNodeGroups(c.cfg, c.ctl, clientSet, allStacks, disableNodegroupEviction, parallel, nodeGroupManager, func(clusterName string, ctl *eks.ClusterProvider, clientSet kubernetes.Interface) {
+		if err := drainAllNodeGroups(ctx, c.cfg, c.ctl, clientSet, allStacks, disableNodegroupEviction, parallel, nodeGroupManager, func(clusterName string, ctl *eks.ClusterProvider, clientSet kubernetes.Interface) {
 			attemptVpcCniDeletion(ctx, clusterName, ctl, clientSet)
 		}, podEvictionWaitPeriod); err != nil {
 			if !force {
@@ -147,7 +149,7 @@ func (c *UnownedCluster) deleteFargateRoleIfExists(ctx context.Context) error {
 }
 
 func (c *UnownedCluster) checkClusterExists(ctx context.Context, clusterName string) error {
-	_, err := c.ctl.Provider.EKS().DescribeCluster(ctx, &awseks.DescribeClusterInput{
+	_, err := c.ctl.AWSProvider.EKS().DescribeCluster(ctx, &awseks.DescribeClusterInput{
 		Name: &c.cfg.Metadata.Name,
 	})
 	if err != nil {
@@ -216,7 +218,7 @@ func (c *UnownedCluster) deleteIAMAndOIDC(ctx context.Context, wait bool, cluste
 func (c *UnownedCluster) deleteCluster(ctx context.Context, wait bool) error {
 	clusterName := c.cfg.Metadata.Name
 
-	out, err := c.ctl.Provider.EKS().DeleteCluster(ctx, &awseks.DeleteClusterInput{
+	out, err := c.ctl.AWSProvider.EKS().DeleteCluster(ctx, &awseks.DeleteClusterInput{
 		Name: &clusterName,
 	})
 
@@ -235,15 +237,15 @@ func (c *UnownedCluster) deleteCluster(ctx context.Context, wait bool) error {
 	}
 
 	logger.Info("waiting for cluster %q to be deleted", clusterName)
-	waiter := awseks.NewClusterDeletedWaiter(c.ctl.Provider.EKS())
+	waiter := awseks.NewClusterDeletedWaiter(c.ctl.AWSProvider.EKS())
 	return waiter.Wait(ctx, &awseks.DescribeClusterInput{
 		Name: &clusterName,
-	}, c.ctl.Provider.WaitTimeout())
+	}, c.ctl.AWSProvider.WaitTimeout())
 }
 
 func (c *UnownedCluster) deleteAndWaitForNodegroupsDeletion(ctx context.Context, waitInterval time.Duration, allStacks []manager.NodeGroupStack) error {
 	clusterName := c.cfg.Metadata.Name
-	eksAPI := c.ctl.Provider.EKS()
+	eksAPI := c.ctl.AWSProvider.EKS()
 
 	// get all managed nodegroups for this cluster
 	nodeGroups, err := eksAPI.ListNodegroups(ctx, &awseks.ListNodegroupsInput{
@@ -296,7 +298,7 @@ func isNotFound(err error) bool {
 
 func (c *UnownedCluster) waitForUnownedNgsDeletion(ctx context.Context, interval time.Duration) *manager.DeleteWaitCondition {
 	condition := func() (bool, error) {
-		nodeGroups, err := c.ctl.Provider.EKS().ListNodegroups(ctx, &awseks.ListNodegroupsInput{
+		nodeGroups, err := c.ctl.AWSProvider.EKS().ListNodegroups(ctx, &awseks.ListNodegroupsInput{
 			ClusterName: &c.cfg.Metadata.Name,
 		})
 		if err != nil {
@@ -312,7 +314,7 @@ func (c *UnownedCluster) waitForUnownedNgsDeletion(ctx context.Context, interval
 
 	return &manager.DeleteWaitCondition{
 		Condition: condition,
-		Timeout:   c.ctl.Provider.WaitTimeout(),
+		Timeout:   c.ctl.AWSProvider.WaitTimeout(),
 		Interval:  interval,
 	}
 }
