@@ -17,7 +17,7 @@ import (
 
 type AssociateIdentityProvidersOptions struct {
 	Providers   []api.IdentityProvider
-	WaitTimeout *time.Duration
+	WaitTimeout time.Duration
 }
 
 func (m *Manager) Associate(ctx context.Context, options AssociateIdentityProvidersOptions) error {
@@ -37,14 +37,14 @@ func (m *Manager) Associate(ctx context.Context, options AssociateIdentityProvid
 					}
 
 					logger.Info("started associating identity provider %s", idP.Name)
-					if options.WaitTimeout != nil {
+					if options.WaitTimeout > 0 {
 						updateWaiter := waiter.NewUpdateWaiter(m.eksAPI, func(options *waiter.UpdateWaiterOptions) {
 							options.RetryAttemptLogMessage = "waiting for update %q in cluster %q to succeed"
 						})
 						if err := updateWaiter.Wait(ctx, &eks.DescribeUpdateInput{
 							Name:     aws.String(m.metadata.Name),
 							UpdateId: update.Id,
-						}, *options.WaitTimeout); err != nil {
+						}, options.WaitTimeout); err != nil {
 							return err
 						}
 					}
