@@ -6,9 +6,9 @@ import (
 	"sort"
 	"strings"
 
-	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/service/eks"
-	"github.com/aws/aws-sdk-go/service/eks/eksiface"
+	"github.com/aws/aws-sdk-go-v2/aws"
+	"github.com/aws/aws-sdk-go-v2/service/eks"
+
 	"github.com/hashicorp/go-version"
 	"github.com/kris-nova/logger"
 	"github.com/pkg/errors"
@@ -17,6 +17,7 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 
 	"github.com/weaveworks/eksctl/pkg/addons"
+	"github.com/weaveworks/eksctl/pkg/awsapi"
 	"github.com/weaveworks/eksctl/pkg/printers"
 )
 
@@ -26,8 +27,8 @@ const (
 	ArchLabel = "kubernetes.io/arch"
 )
 
-func IsKubeProxyUpToDate(input AddonInput) (bool, error) {
-	d, err := input.RawClient.ClientSet().AppsV1().DaemonSets(metav1.NamespaceSystem).Get(context.TODO(), KubeProxy, metav1.GetOptions{})
+func IsKubeProxyUpToDate(ctx context.Context, input AddonInput) (bool, error) {
+	d, err := input.RawClient.ClientSet().AppsV1().DaemonSets(metav1.NamespaceSystem).Get(ctx, KubeProxy, metav1.GetOptions{})
 	if err != nil {
 		if apierrs.IsNotFound(err) {
 			logger.Warning("%q was not found", KubeProxy)
@@ -39,7 +40,7 @@ func IsKubeProxyUpToDate(input AddonInput) (bool, error) {
 		return false, fmt.Errorf("%s has %d containers, expected at least 1", KubeProxy, numContainers)
 	}
 
-	desiredTag, err := getLatestKubeProxyImage(input)
+	desiredTag, err := getLatestKubeProxyImage(ctx, input)
 	if err != nil {
 		return false, err
 	}
@@ -52,7 +53,7 @@ func IsKubeProxyUpToDate(input AddonInput) (bool, error) {
 }
 
 // UpdateKubeProxy updates image tag for kube-system:daemonset/kube-proxy based to match ControlPlaneVersion
-func UpdateKubeProxy(input AddonInput, plan bool) (bool, error) {
+func UpdateKubeProxy(ctx context.Context, input AddonInput, plan bool) (bool, error) {
 	printer := printers.NewJSONPrinter()
 
 	d, err := input.RawClient.ClientSet().AppsV1().DaemonSets(metav1.NamespaceSystem).Get(context.TODO(), KubeProxy, metav1.GetOptions{})
@@ -84,7 +85,7 @@ func UpdateKubeProxy(input AddonInput, plan bool) (bool, error) {
 		return false, fmt.Errorf("unexpected image format %q for %q", *image, KubeProxy)
 	}
 
-	desiredTag, err := getLatestKubeProxyImage(input)
+	desiredTag, err := getLatestKubeProxyImage(ctx, input)
 	if err != nil {
 		return false, err
 	}
@@ -155,9 +156,9 @@ func addArm64NodeSelector(daemonSet *v1.DaemonSet) error {
 	return fmt.Errorf("NodeAffinity not configured on kube-proxy. Either manually update the proxy deployment, or switch to Managed Addons")
 }
 
-func getLatestKubeProxyImage(input AddonInput) (string, error) {
+func getLatestKubeProxyImage(ctx context.Context, input AddonInput) (string, error) {
 	defaultClusterVersion := generateImageVersionFromClusterVersion(input.ControlPlaneVersion)
-	latestEKSReportedVersion, err := getLatestImageVersionFromEKS(input.EKSAPI, input.ControlPlaneVersion)
+	latestEKSReportedVersion, err := getLatestImageVersionFromEKS(ctx, input.EKSAPI, input.ControlPlaneVersion)
 	if err != nil {
 		return "", err
 	}
@@ -191,7 +192,7 @@ func generateImageVersionFromClusterVersion(controlPlaneVersion string) string {
 	return fmt.Sprintf("v%s-eksbuild.1", controlPlaneVersion)
 }
 
-func getLatestImageVersionFromEKS(eksAPI eksiface.EKSAPI, controlPlaneVersion string) (string, error) {
+func getLatestImageVersionFromEKS(ctx context.Context, eksAPI awsapi.EKS, controlPlaneVersion string) (string, error) {
 	controlPlaneMajorMinor, err := versionWithOnlyMajorAndMinor(controlPlaneVersion)
 	if err != nil {
 		return "", err
@@ -201,7 +202,7 @@ func getLatestImageVersionFromEKS(eksAPI eksiface.EKSAPI, controlPlaneVersion st
 		AddonName:         aws.String(KubeProxy),
 	}
 
-	addonInfos, err := eksAPI.DescribeAddonVersions(input)
+	addonInfos, err := eksAPI.DescribeAddonVersions(ctx, input)
 	if err != nil {
 		return "", fmt.Errorf("failed to describe addon versions: %v", err)
 	}
