@@ -6,7 +6,7 @@ import (
 	"net"
 	"reflect"
 
-	"github.com/aws/aws-sdk-go/aws"
+	"github.com/aws/aws-sdk-go-v2/aws"
 	"github.com/pkg/errors"
 
 	"github.com/weaveworks/eksctl/pkg/utils/ipnet"
@@ -400,8 +400,8 @@ func EndpointsEqual(a, b ClusterEndpoints) bool {
 //HasClusterEndpointAccess determines if endpoint access was configured in config file or not
 func (c *ClusterConfig) HasClusterEndpointAccess() bool {
 	if c.VPC != nil && c.VPC.ClusterEndpoints != nil {
-		hasPublicAccess := aws.BoolValue(c.VPC.ClusterEndpoints.PublicAccess)
-		hasPrivateAccess := aws.BoolValue(c.VPC.ClusterEndpoints.PrivateAccess)
+		hasPublicAccess := aws.ToBool(c.VPC.ClusterEndpoints.PublicAccess)
+		hasPrivateAccess := aws.ToBool(c.VPC.ClusterEndpoints.PrivateAccess)
 		return hasPublicAccess || hasPrivateAccess
 	}
 	return true
