@@ -11,6 +11,7 @@ import (
 
 	api "github.com/weaveworks/eksctl/pkg/apis/eksctl.io/v1alpha5"
 	"github.com/weaveworks/eksctl/pkg/ctl/cmdutils"
+	"github.com/weaveworks/eksctl/pkg/eks"
 	"github.com/weaveworks/eksctl/pkg/utils/kubeconfig"
 )
 
@@ -72,7 +73,7 @@ func doWriteKubeconfigCmd(cmd *cmdutils.Cmd, outputPath, roleARN string, setCont
 		outputPath = kubeconfig.AutoPath(cfg.Metadata.Name)
 	}
 
-	ctl, err := cmd.NewProviderForExistingCluster(context.TODO())
+	ctl, err := cmd.NewProviderForExistingCluster(context.Background())
 	if err != nil {
 		return err
 	}
@@ -81,7 +82,7 @@ func doWriteKubeconfigCmd(cmd *cmdutils.Cmd, outputPath, roleARN string, setCont
 		return err
 	}
 
-	kubectlConfig := kubeconfig.NewForKubectl(cfg, ctl.GetUsername(), roleARN, ctl.Provider.Profile())
+	kubectlConfig := kubeconfig.NewForKubectl(cfg, eks.GetUsername(ctl.Status.IAMRoleARN), roleARN, ctl.AWSProvider.Profile())
 	filename, err := kubeconfig.Write(outputPath, *kubectlConfig, setContext)
 	if err != nil {
 		return errors.Wrap(err, "writing kubeconfig")
