@@ -15,7 +15,6 @@ import (
 	ec2types "github.com/aws/aws-sdk-go-v2/service/ec2/types"
 	ekstypes "github.com/aws/aws-sdk-go-v2/service/eks/types"
 	"github.com/aws/aws-sdk-go-v2/service/sts"
-
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/aws/client"
 	"github.com/aws/aws-sdk-go/aws/credentials"
@@ -24,13 +23,12 @@ import (
 	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/cloudformation"
 	"github.com/aws/aws-sdk-go/service/cloudformation/cloudformationiface"
-
 	"github.com/gofrs/flock"
-
 	"github.com/kris-nova/logger"
 	"github.com/pkg/errors"
 	"github.com/spf13/afero"
 	"k8s.io/apimachinery/pkg/runtime"
+	k8sclient "k8s.io/client-go/kubernetes"
 	"k8s.io/client-go/kubernetes/scheme"
 	"sigs.k8s.io/yaml"
 
@@ -47,21 +45,28 @@ import (
 
 // ClusterProvider stores information about the cluster
 type ClusterProvider struct {
+	// KubeProvider offers helper methods to handle Kubernetes operations
+	KubeProvider
+
 	// core fields used for config and AWS APIs
-	Provider api.ClusterProvider
+	AWSProvider api.ClusterProvider
 	// informative fields, i.e. used as outputs
 	Status *ProviderStatus
 }
 
+// KubernetesProvider provides helper methods to handle Kubernetes operations.
+type KubernetesProvider struct {
+	WaitTimeout time.Duration
+	RoleARN     string
+	Signer      api.STSPresigner
+}
+
 //counterfeiter:generate -o fakes/fake_kube_provider.go . KubeProvider
 // KubeProvider is an interface with helper funcs for k8s and EKS that are part of ClusterProvider
 type KubeProvider interface {
 	NewRawClient(spec *api.ClusterConfig) (*kubewrapper.RawClient, error)
+	NewStdClientSet(spec *api.ClusterConfig) (*k8sclient.Clientset, error)
 	ServerVersion(rawClient *kubernetes.RawClient) (string, error)
-	LoadClusterIntoSpecFromStack(ctx context.Context, spec *api.ClusterConfig, stackManager manager.StackManager) error
-	ValidateClusterForCompatibility(ctx context.Context, cfg *api.ClusterConfig, stackManager manager.StackManager) error
-	UpdateAuthConfigMap(nodeGroups []*api.NodeGroup, clientSet kubernetes.Interface) error
-	WaitForNodes(clientSet kubernetes.Interface, ng KubeNodeGroup) error
 }
 
 // ProviderServices stores the used APIs
@@ -120,7 +125,7 @@ type ClusterInfo struct {
 
 // ProviderStatus stores information about the used IAM role and the resulting session
 type ProviderStatus struct {
-	iamRoleARN   string
+	IAMRoleARN   string
 	sessionCreds *credentials.Credentials
 	ClusterInfo  *ClusterInfo
 }
@@ -131,7 +136,7 @@ func New(ctx context.Context, spec *api.ProviderConfig, clusterSpec *api.Cluster
 		spec: spec,
 	}
 	c := &ClusterProvider{
-		Provider: provider,
+		AWSProvider: provider,
 	}
 	// Create a new session and save credentials for possible
 	// later re-use if overriding sessions due to custom URL
@@ -162,7 +167,7 @@ func New(ctx context.Context, spec *api.ProviderConfig, clusterSpec *api.Cluster
 	provider.session = s
 	provider.cfn = cloudformation.New(s)
 
-	cfg, err := newV2Config(spec, c.Provider.Region(), credentialsCacheFilePath)
+	cfg, err := newV2Config(spec, c.AWSProvider.Region(), credentialsCacheFilePath)
 	if err != nil {
 		return nil, err
 	}
@@ -193,10 +198,21 @@ func New(ctx context.Context, spec *api.ProviderConfig, clusterSpec *api.Cluster
 	}
 
 	if clusterSpec != nil {
-		clusterSpec.Metadata.Region = c.Provider.Region()
+		clusterSpec.Metadata.Region = c.AWSProvider.Region()
 	}
 
-	return c, c.checkAuth(ctx)
+	// c.Status.IAMRoleARN is set up in checkAuth which is later on needed by the kubeProvider.
+	if err := c.checkAuth(ctx); err != nil {
+		return nil, err
+	}
+	kubeProvider := &KubernetesProvider{
+		WaitTimeout: spec.WaitTimeout,
+		RoleARN:     c.Status.IAMRoleARN,
+		Signer:      provider.STSPresigner(),
+	}
+	c.KubeProvider = kubeProvider
+
+	return c, nil
 }
 
 // ParseConfig parses data into a ClusterConfig
@@ -246,7 +262,7 @@ func readConfig(configFile string) ([]byte, error) {
 // IsSupportedRegion check if given region is supported
 func (c *ClusterProvider) IsSupportedRegion() bool {
 	for _, supportedRegion := range api.SupportedRegions() {
-		if c.Provider.Region() == supportedRegion {
+		if c.AWSProvider.Region() == supportedRegion {
 			return true
 		}
 	}
@@ -268,15 +284,15 @@ func (c *ClusterProvider) GetCredentialsEnv() ([]string, error) {
 
 // checkAuth checks the AWS authentication
 func (c *ClusterProvider) checkAuth(ctx context.Context) error {
-	output, err := c.Provider.STS().GetCallerIdentity(ctx, &sts.GetCallerIdentityInput{})
+	output, err := c.AWSProvider.STS().GetCallerIdentity(ctx, &sts.GetCallerIdentityInput{})
 	if err != nil {
 		return errors.Wrap(err, "checking AWS STS access – cannot get role ARN for current session")
 	}
 	if output == nil || output.Arn == nil {
 		return fmt.Errorf("unexpected response from AWS STS")
 	}
-	c.Status.iamRoleARN = *output.Arn
-	logger.Debug("role ARN for the current session is %q", c.Status.iamRoleARN)
+	c.Status.IAMRoleARN = *output.Arn
+	logger.Debug("role ARN for the current session is %q", c.Status.IAMRoleARN)
 	return nil
 }
 
@@ -374,8 +390,8 @@ func (c *ClusterProvider) newSession(spec *api.ProviderConfig) *session.Session
 	// https://github.com/kubernetes/kops/blob/master/upup/pkg/fi/cloudup/awsup/aws_cloud.go#L179
 	config := aws.NewConfig().WithCredentialsChainVerboseErrors(true)
 
-	if c.Provider.Region() != "" {
-		config = config.WithRegion(c.Provider.Region()).WithSTSRegionalEndpoint(endpoints.RegionalSTSEndpoint)
+	if c.AWSProvider.Region() != "" {
+		config = config.WithRegion(c.AWSProvider.Region()).WithSTSRegionalEndpoint(endpoints.RegionalSTSEndpoint)
 	}
 
 	config = request.WithRetryer(config, newLoggingRetryer())
@@ -425,5 +441,18 @@ func (c *ClusterProvider) newSession(spec *api.ProviderConfig) *session.Session
 
 // NewStackManager returns a new stack manager
 func (c *ClusterProvider) NewStackManager(spec *api.ClusterConfig) manager.StackManager {
-	return manager.NewStackCollection(c.Provider, spec)
+	return manager.NewStackCollection(c.AWSProvider, spec)
+}
+
+// LoadClusterIntoSpecFromStack uses stack information to load the cluster
+// configuration into the spec
+// At the moment VPC and KubernetesNetworkConfig are respected
+func (c *ClusterProvider) LoadClusterIntoSpecFromStack(ctx context.Context, spec *api.ClusterConfig, stackManager manager.StackManager) error {
+	if err := c.LoadClusterVPC(ctx, spec, stackManager); err != nil {
+		return err
+	}
+	if err := c.RefreshClusterStatus(ctx, spec); err != nil {
+		return err
+	}
+	return c.loadClusterKubernetesNetworkConfig(spec)
 }
