@@ -13,7 +13,7 @@ import (
 
 	"github.com/weaveworks/eksctl/pkg/awsapi"
 
-	"github.com/aws/aws-sdk-go/aws"
+	"github.com/aws/aws-sdk-go-v2/aws"
 	"github.com/pkg/errors"
 
 	cft "github.com/weaveworks/eksctl/pkg/cfn/template"
